<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
  	extension-element-prefixes="redirect">


<xsl:template name="standard-analysis-documentation">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

	<xsl:variable name="file-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="$package-element/@name"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="$subsystem-name"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>

   <xsl:variable name="catalog-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="'packages'"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="'subsystems'"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>

	<h3>Documentation Metrics :</h3>
	<p>The follow the link below to see more details on the documentation in the system.</p>
	<table class="details">
	 	<tr><td style="background-color: white;">
		 		<div align="center">
	              <embed width="460" height="275" src="../img/javadocs-per-method-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
            <td style="background-color: white;"/>
            <td style="background-color: white;">

	            <div align="center">
	              <embed width="460" height="275" src="../img/javadoc-lines-per-ncss-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
	 	</tr>
	 </table>

	<a href="javascript:winpopanalysisdetails('documentation-details-popup-{$file-identifier}.html')">[Documentation Metrics Details]</a><br/>

	 <redirect:write file="{$docs-home}/{$catalog-identifier}/documentation-details-popup-{$file-identifier}.html">
		 <xsl:call-template name="standard-analysis-documentation-details">
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
   	 </redirect:write>

    <redirect:write file="{$docs-home}/img/javadocs-per-method-image-{$file-identifier}.svg">

          <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Javadocs per Method'"/>
            <xsl:with-param name="primary-metric-group" select="'documentation-metrics'"/>
            <xsl:with-param name="primary-metric" select="'javadocs'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'functions'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

    <redirect:write file="{$docs-home}/img/javadoc-lines-per-ncss-image-{$file-identifier}.svg">

          <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Javadoc Lines per Source Statements'"/>
            <xsl:with-param name="primary-metric-group" select="'documentation-metrics'"/>
            <xsl:with-param name="primary-metric" select="'javadoc-lines'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'ncss'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

</xsl:template>

<xsl:template name="standard-analysis-documentation-details">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>
	<html>
	<head>
         <link rel="stylesheet" type="text/css" href="../stylesheet.css"/>
	</head>
    <body>

	<table class="details">
		<tr><th>Version</th><th>Date</th><th>Javadocs[JD]</th><th>[JD]/methods</th><th>Javadoc Lines [JDL]</th><th>[JDL]/[SS]</th><th>Single Comment<br/>Lines [SCL]</th><th>[SCL]/[SS]</th><th>Multi Comment<br/>Lines [MCL]</th><th>[MCL]/[SS]</th></tr>
		<xsl:for-each select="$reports-element/report">
			<xsl:sort select="@seq-id"/>
			<xsl:variable name="current-seq-id" select="@seq-id"/>

	   		<xsl:choose>
	 			<xsl:when test="$single-package='true'">
			 		<xsl:if test="$package-element/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]">
				 		<xsl:variable name="current-seq-id" select="@seq-id"/>
						<xsl:variable name="ncss" select="$package-element/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="methods" select="$package-element/statistics/source-metrics/functions/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="JD" select="$package-element/statistics/documentation-metrics/javadocs/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="JDL" select="$package-element/statistics/documentation-metrics/javadoc-lines/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="SCL" select="$package-element/statistics/documentation-metrics/single-comment-lines/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="MCL" select="$package-element/statistics/documentation-metrics/multi-comment-lines/value[@seq-id=$current-seq-id]/@value"/>
						<tr>
							<td><xsl:value-of select="version"/></td>
							<td><xsl:value-of select="date"/></td>
							<td><xsl:value-of select="$JD"/></td>
							<td><xsl:value-of select="format-number($JD div $methods, '#.##')"/></td>
							<td><xsl:value-of select="$JDL"/></td>
							<td><xsl:value-of select="format-number($JDL div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$SCL"/></td>
							<td><xsl:value-of select="format-number($SCL div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$MCL"/></td>
							<td><xsl:value-of select="format-number($MCL div $ncss, '#.##')"/></td>
						</tr>
					</xsl:if>
				</xsl:when>
		        <xsl:otherwise>
		            <xsl:if test="$packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]">
			            <xsl:variable name="current-seq-id" select="@seq-id"/>
						<xsl:variable name="ncss" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="methods" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/functions/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="JD" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/documentation-metrics/javadocs/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="JDL" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/documentation-metrics/javadoc-lines/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="SCL" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/documentation-metrics/single-comment-lines/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="MCL" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/documentation-metrics/multi-comment-lines/value[@seq-id=$current-seq-id]/@value)"/>
						<tr>
							<td><xsl:value-of select="version"/></td>
							<td><xsl:value-of select="date"/></td>
							<td><xsl:value-of select="$JD"/></td>
							<td><xsl:value-of select="format-number($JD div $methods, '#.##')"/></td>
							<td><xsl:value-of select="$JDL"/></td>
							<td><xsl:value-of select="format-number($JDL div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$SCL"/></td>
							<td><xsl:value-of select="format-number($SCL div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$MCL"/></td>
							<td><xsl:value-of select="format-number($MCL div $ncss, '#.##')"/></td>
						</tr>
					</xsl:if>
		        </xsl:otherwise>
	        </xsl:choose>
		</xsl:for-each>
	</table>

	</body>
	</html>

</xsl:template>

</xsl:stylesheet>
