<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
  	extension-element-prefixes="redirect">

	<xsl:include href="xradar://stylesheets/radar/graph/relations-matrix.xsl"/>
    <xsl:include href="xradar://stylesheets/radar/statics/report/framework/master-report-common-link.xsl"/>

    <xsl:key name="duplicated-class" match="duplications/duplication/class" use="@name"/>

    <xsl:param name="docs-home"/>
    <xsl:param name="radar-config-file"/>
    <xsl:param name="log"/>

	<xsl:variable name="radar-config-doc" select="document($radar-config-file)"/>
	<xsl:variable name="graph-width" select="'5000'"/>
	<xsl:variable name="graph-height" select="'5000'"/>

    <xsl:variable   name="color-ok"   select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 3]/@color"/>
    <xsl:variable   name="color-warn" select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 2]/@color"/>
    <xsl:variable   name="color-ko"   select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 1]/@color"/>

	<xsl:template match="radar-report">

	    <xsl:choose>
	        <xsl:when test="$log = 'true'">
        	    <xsl:message>
Statics produce duplication graph:
docs-home:       <xsl:value-of   select="$docs-home"/>
radar-config:    <xsl:value-of   select="$radar-config-file"/>
input:           <xsl:value-of   select="@date"/>
                </xsl:message>
            </xsl:when>
	    </xsl:choose>
		<xsl:variable name="subsystem-code-duplication-matrix-filename"><xsl:value-of select="concat($docs-home,'/img/subsystem-code-duplication-matrix.xml')"/></xsl:variable>
        <redirect:write file="{$subsystem-code-duplication-matrix-filename}">
			<xsl:apply-templates select="packages" mode="subsystem-code-duplication-matrix"/>
		</redirect:write>


        <xsl:variable name="image-input-doc" select="document(concat('file://',concat($docs-home,'/img/subsystem-code-duplication-matrix.xml')))"/>

		<xsl:variable name="test"><xsl:value-of select="concat($docs-home,'/img/subsystem-code-duplication-matrix.xml')"/></xsl:variable>

		<xsl:variable name="subsystem-code-duplication-matrix-svg-filename"><xsl:value-of select="concat($docs-home,'/img/subsystem-code-duplication-matrix.svg')"/></xsl:variable>
        <redirect:write file="{$subsystem-code-duplication-matrix-svg-filename}">
			<xsl:apply-templates select="$image-input-doc/relations"/>
		</redirect:write>

	</xsl:template>


	<xsl:template match="packages" mode="subsystem-code-duplication-matrix">
		<xsl:variable name="packages-element" select="current()"/>
        <relations>
            <xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
                <xsl:variable name="subsystem-name" select="normalize-space(name)"/>
                <xsl:variable name="subsystem-position" select="position()"/>
                <xsl:variable name="subsystem-total-classes" select="count($packages-element/package[@subsystem = $subsystem-name]/classes/descendant::class[(methods/method) or (../../statistics/source-metrics/ncss &gt; 0)])"/>

                <xsl:if test="$subsystem-total-classes &gt; 0">
                    <module name="{$subsystem-name}" size="{$subsystem-total-classes}" id="{@id}" seq-number="{$subsystem-position}">
                            <xsl:for-each select="$packages-element/package[@subsystem = $subsystem-name]/classes/descendant::class[methods/method]">
                                <xsl:sort select="@name"/>
                                <xsl:variable name="class-name" select="concat(../../@name,'.',@name)"/>
                                <xsl:variable name="package-name" select="../../@name"/>
                                <xsl:if test="duplications">
                                    <group>
                                        <link><xsl:value-of select="concat('../classes/',$package-name,'-classes.html#CL',$class-name)"/></link>
										<link><xsl:call-template name="class-url">
											<xsl:with-param name="class-name" select="$class-name"/>
											<xsl:with-param name="package-name" select="$package-name"/>
											</xsl:call-template>
										</link>
                                        <element seq-id="{position()}" module-seq-number="{$subsystem-position}" name="{$class-name}" weight="{count(duplications/duplication[descendant::classref/@name = $class-name])}" source="true" legal="false">
                                            <xsl:if test="count(duplications/descendant::classref[@name = $class-name]) &gt; count(duplications/descendant::classref[not(@name = $class-name)])"><xsl:attribute name="internal-relation">true</xsl:attribute></xsl:if>
                                        </element>
                                        <xsl:for-each select="duplications/descendant::classref">
                                            <xsl:variable name="this-class-name" select="@name"/>
                                            <xsl:variable name="this-position" select="position()"/>

                                            <xsl:if test="not($this-class-name = $class-name) and
                                                            count(../../../duplications/descendant::classref[(position() &lt;= $this-position) and (@name = $this-class-name)]) = 1">
                                                <element name="{@name}" seq-id="?" module-seq-number="?"  weight="{count(../../../duplications/duplication[descendant::classref/@name = $this-class-name])}" source="false"/>
                                            </xsl:if>
                                        </xsl:for-each>
                                    </group>
                                </xsl:if>
                            </xsl:for-each>
                    </module>
                </xsl:if>
            </xsl:for-each>
        </relations>

	</xsl:template>



    <xsl:template match="relations">
		<xsl:variable name="packages-element" select="current()"/>

		<xsl:call-template name="relations-matrix-graph">
	  		<xsl:with-param name="title" select="'Duplication Matrix'"/>
	  		<xsl:with-param name="units" select="'Duplications'"/>
	  		<xsl:with-param name="width" select="$graph-width"/>
	  		<xsl:with-param name="height" select="$graph-height"/>
	  		<xsl:with-param name="relations-nodeset">
                <xsl:copy>
                    <xsl:apply-templates select="@*|node()"/>
                </xsl:copy>
            </xsl:with-param>
		</xsl:call-template>
	</xsl:template>

    <xsl:template match="group">
	   <xsl:copy>
	      <xsl:apply-templates select="@*|node()"/>
	   </xsl:copy>
	</xsl:template>

    <xsl:template match="element">
        <xsl:choose>
            <xsl:when test="(@module-seq-number = '?') or (@seq-id = '?') ">
                <xsl:variable name="element-name" select="@name"/>
                <xsl:if test="../../../descendant::element[($element-name = @name) and not(@seq-id = '?')]">
                    <xsl:copy>
                    	<xsl:attribute name="module-seq-number"><xsl:value-of select="../../../descendant::element[($element-name = @name) and not(@module-seq-number = '?')]/@module-seq-number"/></xsl:attribute>
                      	<xsl:attribute name="seq-id"><xsl:value-of select="../../../descendant::element[($element-name = @name) and not(@seq-id = '?')]/@seq-id"/></xsl:attribute>
                      	<xsl:apply-templates select="@name|@weight|@source"/>
                    </xsl:copy>
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy>
                  <xsl:apply-templates select="@*|node()"/>
                </xsl:copy>
            </xsl:otherwise>
        </xsl:choose>
	</xsl:template>

    <!-- Copy all nodes from here. Can be overridden by a more specific XPath -->
	<xsl:template match="@*|node()">
	   <xsl:copy>
	      <xsl:apply-templates select="@*|node()"/>
	   </xsl:copy>
	</xsl:template>

</xsl:stylesheet>
