<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
    xmlns:xalan="http://xml.apache.org/xalan"
  	extension-element-prefixes="redirect">

	<xsl:include href="xradar://stylesheets/radar/graph/spider-graph.xsl"/>
	<xsl:include href="xradar://stylesheets/radar/graph/simple-histogram-graph.xsl"/>
	<xsl:include href="xradar://stylesheets/radar/statics/report/framework/master-report-common-link.xsl"/>

	<xsl:key name="subsystems" match="package" use="subsystem/@name"/>

	<xsl:param name="root-path"/>
    <xsl:param name="docs-home"/>
	<xsl:param name="radar-config-file"/>
	<xsl:param name="log"/>

	<xsl:variable name="radar-config-doc" select="document($radar-config-file)"/>
	<xsl:variable name="graph-width" select="'400'"/>
	<xsl:variable name="graph-height" select="'400'"/>
	<xsl:variable name="quality-doc-prefix" select="'subsystem_quality_report_'"/>
	<xsl:variable name="system-quality-doc" select="document(concat('file://',concat($docs-home,'/xml/reports/','system_quality_report.xml')))"/>
	<xsl:variable name="path-to-root" select="''"/>

	<xsl:template match="radar-report">

		<xsl:choose>
			<xsl:when test="$log = 'true'">
				<xsl:message>
*********************statics-report-produce-module-graphs**************************
root-path:<xsl:value-of select="$root-path"/>
docs-home:<xsl:value-of select="$docs-home"/>
radar-config:<xsl:value-of select="$radar-config-file"/>
log:<xsl:value-of select="$log"/>
***********************************************************************************
				</xsl:message>
			</xsl:when>
		</xsl:choose>


		<redirect:write file="{$docs-home}/img/spider-graph-system.svg">
			<xsl:call-template name="spider-graph">
				<xsl:with-param name="title"/>
				<xsl:with-param name="width" select="$graph-width"/>
				<xsl:with-param name="height" select="$graph-height"/>
				<xsl:with-param name="metrics-nodeset">
					<metrics>
						<xsl:for-each select="$system-quality-doc/metric/metric/metric">
								<metric
									name="{@abbreviation}"
									value="{value}"
									median="{value}"
									max="1"/>
						</xsl:for-each>
					</metrics>
				</xsl:with-param>
			</xsl:call-template>
		</redirect:write>

        <xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
            <redirect:write file="{$docs-home}/img/spider-graph-subsystem-{name}.svg">
                <xsl:variable name="subsystem-name" select="normalize-space(name)"/>
                <xsl:call-template name="spider-graph">
                    <xsl:with-param name="title"/>
                    <xsl:with-param name="width" select="$graph-width"/>
                    <xsl:with-param name="height" select="$graph-height"/>
                    <xsl:with-param name="metrics-nodeset">
                        <metrics>
			    <xsl:variable name="subsystem-quality-filename">
					<xsl:value-of select="concat($docs-home,'/xml/reports/',$quality-doc-prefix,$subsystem-name,'.xml')"/>
			    </xsl:variable>
                            <xsl:variable name="subsystem-quality-doc" select="document(concat('file://',$subsystem-quality-filename))"/>

							<xsl:for-each select="$subsystem-quality-doc/metric/metric/metric">
								 <xsl:variable name="abb" select="@abbreviation"/>
								 <metric
									 name="{@abbreviation}"
									 value="{value}"
									 median="{0.0 + $system-quality-doc/descendant::metric[@abbreviation = $abb]}"
									 max="1"/>
							</xsl:for-each>
                        </metrics>
                    </xsl:with-param>
                </xsl:call-template>
            </redirect:write>
        </xsl:for-each>

        <redirect:write file="{$docs-home}/img/subsystem-quality-histogram.svg">

			<xsl:call-template name="simple-histogram-graph">
				  <xsl:with-param name="text-x-axis" 	select="'Subsystem'"/>
				  <xsl:with-param name="text-y-axis" 	select="'Total Quality '"/>
				  <xsl:with-param name="width" 		select="$graph-width"/>
				  <xsl:with-param name="height" 	select="$graph-height"/>
				  <xsl:with-param name="color-ok"   	select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 3]/@color"/>
				  <xsl:with-param name="color-warn" 	select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 2]/@color"/>
				  <xsl:with-param name="color-ko"   	select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 1]/@color"/>
				  <xsl:with-param name="point-nodeset">
					  <points>
						  <xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
							  <xsl:variable name="subsystem-name" select="normalize-space(name)"/>
							  <xsl:variable name="subsystem-quality-doc" select="document(concat('file://',concat($docs-home,'/xml/reports/',$quality-doc-prefix,$subsystem-name,'.xml')))"/>
							  <point>
								  <x-label><xsl:value-of select="$subsystem-name"/></x-label>
								  <y-coordinate><xsl:value-of select="$subsystem-quality-doc/metric/value"/></y-coordinate>
								  <link><xsl:call-template name="svg-subsystem-url">
										<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
										<xsl:with-param name="path-to-root" select="'../'"/>
									  </xsl:call-template></link>
							  </point>
						  </xsl:for-each>
					  </points>
				  </xsl:with-param>
			</xsl:call-template>
        </redirect:write>

	</xsl:template>

</xsl:stylesheet>
