<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
    extension-element-prefixes="redirect">

<!--	FIXME: find a way to centralize color !-->
	<xsl:variable   name="color-ok"
		select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 3]/@color"/>
	<xsl:variable   name="color-ko"
		select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 1]/@color"/>
	<xsl:variable   name="color-warn"
		select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 2]/@color"/>

<xsl:template match="IntegratedAnalysis" mode="scorecard-architecture">

	<xsl:variable name="packages-element" select="Packages"/>

   	<html>
      <head>
         <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
      </head>
      <body>

         <xsl:call-template name="page-header">
  	  	   <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
  	  	   <xsl:with-param name="page-name" select="'architecture'"/>
  	  	   <xsl:with-param name="dynamics-page-name" select="'architecture'"/>
  	  	   <xsl:with-param name="root-element" select="current()"/>
  	     </xsl:call-template>

		<h3>Module Dependencies</h3>
      	The module is green if dependencies from the module are legal. If illegal dependecies the subsystem is
      	<span class="warn">like this</span>.
		<p/>
      	Roll over the figure with the mouse to see dependencies. Legal dependencies are marked
      	<span class="ok">like this</span>. The illegal ones are
      	marked <span class="ko">like this</span>.
		<p/>
		<table width="100%" class="details">
		    <tr>
				<td style="background-color: white;">
			 		<div>
		              <embed width="800" height="400" src="img/subsystem-dependency-graph.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
		            </div>
	            </td>
			</tr>

		    <xsl:if test="count($radar-config-doc/radar-config/subsystems/subsystem) &gt; 1">
				<tr>
					<td colspan="3" style="background-color: white;">
						<table class="details">
							    <xsl:call-template name="metric-header-dependencies"/>

							    <xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
									<xsl:variable name="subsystem-name" select="normalize-space(name)"/>
									<xsl:variable name="file-name"><xsl:call-template name="subsystem-url">
										<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
										<xsl:with-param name="anchor" select="'dependencies'"/>
									</xsl:call-template></xsl:variable>
									<xsl:call-template name="subsystem-dependancies">
										<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
										<xsl:with-param name="subsystem-link" select="$file-name"/>
										<xsl:with-param name="packages-element" select="$packages-element"/>
									</xsl:call-template>
								</xsl:for-each>
						</table>
					</td>
				</tr>
			</xsl:if>
		</table>

		<p/>
		<h3>Design Structrure Matrix</h3>
		<p>
            In the matrix below, all marks symbilises a coupling from one package to the other. In a perfect layered system
			all marks are below the main diagonal. See <a href="http://www.dsmweb.org/">http://www.dsmweb.org/</a> for more on the theory. A mark is
			green if the dependency is legal. It is red if it is illegal.
        </p>
		<p>
            By pointing your mouse over the dots you will see the details of that coupling. Click to
            go to the package.
        </p>
        <br/>
		<table width="100%" class="details" align="center">
			<tr>
				<td style="background-color: white;">
			 		<div align="top">
		              <embed width="800" height="800" src="img/subsystem-package-coupling-matrix.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
		            </div>
	            </td>
	        </tr>
	    </table>

      </body>
   </html>


</xsl:template>

<xsl:template name="metric-header-dependencies">
	<xsl:param name="header-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="row-type"/>

	<tr>
       <th>Subsystem Dependencies</th>
		<xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
			<th><xsl:value-of select="normalize-space(name)"/></th>
		</xsl:for-each>
		<th>External Packages</th>
    </tr>
</xsl:template>

<xsl:template name="subsystem-dependancies">
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="subsystem-link"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

	<tr>
		<td>
			<a href="{$subsystem-link}">
		       <xsl:value-of select="$subsystem-name"/>
		    </a>
		</td>

		<xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
		<xsl:variable name="this-subsystem-name" select="normalize-space(name)"/>
		<xsl:variable name="this-subsystem-id" select="@id"/>
		<td>
			 <xsl:choose>
			 	<xsl:when test="$single-package='true'">
			 		<xsl:if test="(sum($package-element/Stats/dependancy-metrics/subsystem[@name = $this-subsystem-name])&gt; 0)
			 						and (not($radar-config-doc/radar-config/subsystems/subsystem[normalize-space(name) = $package-element/subsystem/@name]/legal-subordinates/subsystem[@id = $this-subsystem-id]))">
			 			<xsl:attribute name="style">background-color: <xsl:value-of select="$color-warn"/></xsl:attribute>
					</xsl:if>
					<xsl:value-of select="sum($package-element/Stats/dependancy-metrics/subsystem[@name = $this-subsystem-name])"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="(sum($packages-element/Package[subsystem/@name=$subsystem-name]/Stats/dependancy-metrics/subsystem[@name = $this-subsystem-name])&gt; 0)
									and (not($radar-config-doc/radar-config/subsystems/subsystem[normalize-space(name) = $subsystem-name]/legal-subordinates/subsystem[@id = $this-subsystem-id]))">
							<xsl:attribute name="style">background-color: <xsl:value-of select="$color-warn"/></xsl:attribute>
						</xsl:when>
						<xsl:when test="not($radar-config-doc/radar-config/subsystems/subsystem[normalize-space(name) = $subsystem-name]/legal-subordinates/subsystem[@id = $this-subsystem-id])">
							<xsl:attribute name="style">background-color: #C0C0C0</xsl:attribute> <!--#CCCCFF;-->
						</xsl:when>
					</xsl:choose>
					<xsl:value-of select="sum($packages-element/Package[subsystem/@name=$subsystem-name]/Stats/dependancy-metrics/subsystem[@name = $this-subsystem-name])"/>
				</xsl:otherwise>
			</xsl:choose>
		</td>
		</xsl:for-each>

       	<td>
			 <xsl:choose>
			 	<xsl:when test="$single-package='true'">
					<xsl:value-of select="sum($package-element/Stats/dependancy-metrics/subsystem[@name = 'External'])"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="sum($packages-element/Package[subsystem/@name=$subsystem-name]/Stats/dependancy-metrics/subsystem[@name = 'External'])"/>
				</xsl:otherwise>
			</xsl:choose>
       </td>

    </tr>
</xsl:template>

</xsl:stylesheet>
